pub struct Credential<'a> {
pub common_fields: CommonFields<'a, CredentialFlag>,
pub subject: Cow<'a, str>,
pub issuer: Cow<'a, str>,
pub credential_type: Cow<'a, str>,
pub expiration: Option<u32>,
pub uri: Option<Cow<'a, str>>,
pub subject_node: Option<Cow<'a, str>>,
pub issuer_node: Cow<'a, str>,
pub previous_txn_id: Cow<'a, str>,
pub previous_txn_lgr_seq: u32,
}Expand description
A Credential object is an on-ledger representation of a credential.
<https://github.com/XRPLF/XRPL-Standards/tree/master/XLS-0070-credentials>
Fields
common_fields: CommonFields<'a, CredentialFlag>The base fields for all ledger object models.
subject: Cow<'a, str>The account the credential is for.
issuer: Cow<'a, str>The account that issued the credential.
credential_type: Cow<'a, str>A hex-encoded value identifying the credential type from this issuer.
expiration: Option<u32>Optional expiration for the credential.
uri: Option<Cow<'a, str>>Optional additional data, represented as a hex-encoded string.
subject_node: Option<Cow<'a, str>>A hint indicating which page of the subject’s owner directory links to this object. Omitted for self-issued credentials, which only appear in the issuer’s owner directory.
issuer_node: Cow<'a, str>A hint indicating which page of the issuer’s owner directory links to this object.
previous_txn_id: Cow<'a, str>The identifying hash of the transaction that most recently modified this object.
previous_txn_lgr_seq: u32The index of the ledger containing the transaction that most recently modified this object.
Implementations
Sourceimpl<'a> Credential<'a>
impl<'a> Credential<'a>
pub fn new( index: Option<Cow<'a, str>>, ledger_index: Option<Cow<'a, str>>, subject: Cow<'a, str>, issuer: Cow<'a, str>, credential_type: Cow<'a, str>, expiration: Option<u32>, uri: Option<Cow<'a, str>>, subject_node: Option<Cow<'a, str>>, issuer_node: Cow<'a, str>, previous_txn_id: Cow<'a, str>, previous_txn_lgr_seq: u32, ) -> Self