pub struct DID<'a> {
pub common_fields: CommonFields<'a, NoFlags>,
pub account: Cow<'a, str>,
pub did_document: Option<Cow<'a, str>>,
pub data: Option<Cow<'a, str>>,
pub uri: Option<Cow<'a, str>>,
pub owner_node: Cow<'a, str>,
pub previous_txn_id: Cow<'a, str>,
pub previous_txn_lgr_seq: u32,
}Expand description
The DID object type holds references to, or data associated with, a single
Decentralized Identifier (DID).
<https://xrpl.org/docs/references/protocol/ledger-data/ledger-entry-types/did>
Fields
common_fields: CommonFields<'a, NoFlags>The base fields for all ledger object models.
See Ledger Object Common Fields:
<https://xrpl.org/ledger-entry-common-fields.html>
account: Cow<'a, str>The account that controls the DID.
did_document: Option<Cow<'a, str>>The W3C standard DID document associated with the DID. Limited to a maximum length of 256 bytes.
data: Option<Cow<'a, str>>The public attestations of identity credentials associated with the DID. Limited to a maximum length of 256 bytes.
uri: Option<Cow<'a, str>>The Universal Resource Identifier that points to the corresponding DID document or the data associated with the DID. Limited to a maximum length of 256 bytes.
owner_node: Cow<'a, str>A hint indicating which page of the owner directory links to this object.
previous_txn_id: Cow<'a, str>The identifying hash of the transaction that most recently modified this object.
previous_txn_lgr_seq: u32The index of the ledger that contains the transaction that most recently modified this object.
Implementations