pub struct Oracle<'a> {
pub common_fields: CommonFields<'a, NoFlags>,
pub owner: Cow<'a, str>,
pub provider: Cow<'a, str>,
pub asset_class: Cow<'a, str>,
pub price_data_series: Vec<PriceData>,
pub last_update_time: u32,
pub uri: Option<Cow<'a, str>>,
pub owner_node: Cow<'a, str>,
pub previous_txn_id: Cow<'a, str>,
pub previous_txn_lgr_seq: u32,
pub oracle_document_id: Option<u32>,
}Expand description
The Oracle ledger entry holds data associated with a single price oracle object.
See Oracle:
<https://xrpl.org/docs/references/protocol/ledger-data/ledger-entry-types/oracle>
Fields
common_fields: CommonFields<'a, NoFlags>The base fields for all ledger object models.
See Ledger Object Common Fields:
<https://xrpl.org/ledger-entry-common-fields.html>
owner: Cow<'a, str>The XRPL account with update and delete privileges for the oracle.
provider: Cow<'a, str>An arbitrary value that identifies an oracle provider.
asset_class: Cow<'a, str>Describes the type of asset, such as “currency”, “commodity”, or “NFT”.
price_data_series: Vec<PriceData>An array of up to 10 PriceData objects, representing the price information.
last_update_time: u32The time the data was last updated, represented in the ripple epoch.
uri: Option<Cow<'a, str>>An optional Universal Resource Identifier to reference price data off-chain.
owner_node: Cow<'a, str>A hint indicating which page of the owner directory links to this entry.
previous_txn_id: Cow<'a, str>The identifying hash of the transaction that most recently modified this entry.
previous_txn_lgr_seq: u32The index of the ledger that contains the transaction that most recently modified this entry.
oracle_document_id: Option<u32>A unique identifier of the price oracle for the account, if present in the ledger entry returned by the server.