pub struct SubmitMultisigned<'a> {
pub common_fields: CommonFields<'a>,
pub tx_json: Value,
pub fail_hard: Option<bool>,
}Expand description
The server_state command asks the server for various machine-readable information about the rippled server’s current state. The response is almost the same as the server_info method, but uses units that are easier to process instead of easier to read. (For example, XRP values are given in integer drops instead of scientific notation or decimal values, and time is given in milliseconds instead of seconds.)
See Submit Multisigned:
<https://xrpl.org/submit_multisigned.html>
Fields
common_fields: CommonFields<'a>The common fields shared by all requests.
tx_json: Valuefail_hard: Option<bool>If true, and the transaction fails locally, do not retry or relay the transaction to other servers.
Implementations