#[non_exhaustive]pub enum XRPLSignerListSetException {
ValueCausesValueDeletion {
field1: String,
field2: String,
},
InvalidValueForValueDeletion {
field: String,
expected: u32,
found: u32,
},
CollectionTooFewItems {
field: String,
min: usize,
found: usize,
},
CollectionTooManyItems {
field: String,
max: usize,
found: usize,
},
CollectionItemDuplicate {
field: String,
found: String,
},
CollectionInvalidItem {
field: String,
found: String,
},
SignerQuorumExceedsSignerWeight {
max: u32,
found: u32,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ValueCausesValueDeletion
A field was defined that another field definition would delete.
InvalidValueForValueDeletion
A field is expected to have a certain value to be deleted.
CollectionTooFewItems
A collection has too few items in it.
CollectionTooManyItems
A collection has too many items in it.
CollectionItemDuplicate
A collection is not allowed to have duplicates in it.
CollectionInvalidItem
A collection contains an invalid value.
SignerQuorumExceedsSignerWeight