OracleSet

Struct OracleSet 

pub struct OracleSet<'a> {
    pub common_fields: CommonFields<'a, NoFlags>,
    pub oracle_document_id: u32,
    pub provider: Option<Cow<'a, str>>,
    pub uri: Option<Cow<'a, str>>,
    pub asset_class: Option<Cow<'a, str>>,
    pub last_update_time: u32,
    pub price_data_series: Vec<PriceData>,
}
An OracleSet transaction creates or updates an Oracle ledger entry.

See OracleSet: <https://xrpl.org/docs/references/protocol/transactions/types/oracleset>

Fields

common_fields: CommonFields<'a, NoFlags>

The base fields for all transaction models.

See Transaction Common Fields: <https://xrpl.org/transaction-common-fields.html>

oracle_document_id: u32

A unique identifier of the price oracle for the account.

provider: Option<Cow<'a, str>>

An arbitrary value that identifies an oracle provider, such as Chainlink, Band, or DIA. This field is a string, up to 256 ASCII hex encoded characters (128 bytes).

uri: Option<Cow<'a, str>>

An optional Universal Resource Identifier to reference price data off-chain. This field is limited to 256 bytes.

asset_class: Option<Cow<'a, str>>

Describes the type of asset, such as “currency”, “commodity”, or “NFT”. This field is a string, up to 16 ASCII hex encoded characters (8 bytes).

last_update_time: u32

The time the data was last updated, represented in the ripple epoch.

price_data_series: Vec<PriceData>

An array of 1 to 10 PriceData objects, each representing one price data entry.

Implementations

Source

impl<'a> OracleSet<'a>

pub fn new( account: Cow<'a, str>, account_txn_id: Option<Cow<'a, str>>, fee: Option<XRPAmount<'a>>, last_ledger_sequence: Option<u32>, memos: Option<Vec<Memo>>, sequence: Option<u32>, signers: Option<Vec<Signer>>, source_tag: Option<u32>, ticket_sequence: Option<u32>, oracle_document_id: u32, provider: Option<Cow<'a, str>>, uri: Option<Cow<'a, str>>, asset_class: Option<Cow<'a, str>>, last_update_time: u32, price_data_series: Vec<PriceData>, ) -> Self

pub fn with_oracle_document_id(self, id: u32) -> Self

Set the oracle document ID

pub fn with_provider(self, provider: Cow<'a, str>) -> Self

Set the provider

pub fn with_uri(self, uri: Cow<'a, str>) -> Self

Set the URI

pub fn with_asset_class(self, asset_class: Cow<'a, str>) -> Self

Set the asset class

pub fn with_last_update_time(self, time: u32) -> Self

Set the last update time

pub fn with_price_data_series(self, series: Vec<PriceData>) -> Self

Set the price data series