pub struct PriceData {
pub base_asset: String,
pub quote_asset: String,
pub asset_price: Option<String>,
pub scale: Option<u8>,
}Expand description
Represents a single price data entry in an Oracle’s PriceDataSeries.
See OracleSet:
<https://xrpl.org/docs/references/protocol/transactions/types/oracleset>
Fields
base_asset: Stringquote_asset: Stringasset_price: Option<String>The token pair’s price. When omitted on an OracleSet update, rippled deletes the existing price data entry for this base/quote pair.
scale: Option<u8>Decimal scale factor. Actual price = asset_price × 10^(−scale). Range 0–20. Must be present when asset_price is present, and absent when asset_price is absent.